==> apemanlocale-5.0.1.tgz: package/lib/apemanlocale.js <==
/**
 * Define locale message resource.
 * @function apemanlocale
 * @param {string} [dirname="locales"] - Directory path which contains locale messages.
 * @param {object} [options] - Optional settings.
 * @param {object} [options.default='en'] - Default lang.
 * @returns {object} - Locales
 */

'use strict'

const argx = require('argx')
const print = require('./print')
const validate = require('./validate')
const fromFiles = require('./localing/from_files')
const sortLangs = require('./localing/sort_langs')
const defaults = require('./defaults')
const Locales = require('locale').Locales

/** @lends apemanlocale */
function apemanlocale (dirname, options) {
  let args = argx(arguments)
  options = args.pop('object') || {}
  dirname = args.shift('string') || 'locales'
  let defaultLang = options.default || 'en'

  let buildin = options.buildin ? defaults : {}
  let datasource = fromFiles(dirname, defaultLang, buildin)
  let langs = sortLangs(Object.keys(datasource))
  let supported = new Locales(langs)

  /**
   * Locale object.
   * @param {string} lang - Lang to resolve.
   * @returns {object} - Locale object for a lang.
   */
  function locales (lang) {
    let best = new Locales(lang).best(supported)
    return datasource[ best ]
  }

  // noinspection Eslint
  locales.__proto__ = Object.assign(new Function(''), {
    src: dirname,
    defaultLang: defaultLang,
    langs: langs,
    print () {
      print(locales)
      return locales
    },
    validate () {
      validate(locales)
      return locales
    },
    toJSON() {
      return langs.reduce((result, lang) => Object.assign(result, {
        [lang]: locales(lang).toJSON()
      }), {})
    }
  })
  Object.assign(locales, datasource)

  return locales
}

module.exports = apemanlocale

==> apemanlocale-5.0.20.tgz: package/lib/apemanlocale.js <==
/**
 * Define locale message resource.
 * @function apemanlocale
 * @param {string} [dirname="locales"] - Directory path which contains locale messages.
 * @param {object} [options] - Optional settings.
 * @param {object} [options.default='en'] - Default lang.
 * @param {boolean} [options.fallback] - Use default lang as fallback
 * @param {boolean} [options.buildin] - Use buildin langs
 * @returns {object} - Locales
 */

'use strict'

const print = require('./print')
const validate = require('./validate')
const fromFiles = require('./localing/from_files')
const sortLangs = require('./localing/sort_langs')
const registerFallback = require('./localing/register_fallback')
const { Locales } = require('locale')

/** @lends apemanlocale */
function apemanlocale (dirname = 'locales', options = {}) {
  let defaultLang = options.default || 'en'
  let buildin = options.buildin ? require('./buildin') : {}

  let datasource = fromFiles(dirname, buildin)

  if (options.fallback) {
    for (let lang of Object.keys(datasource)) {
      if (lang !== defaultLang) {
        registerFallback(datasource[ lang ], datasource[ defaultLang ])
      }
    }
  }

  let langs = sortLangs(Object.keys(datasource))
  let supported = new Locales(langs)

  /**
   * Locale object.
   * @param {string} lang - Lang to resolve.
   * @returns {object} - Locale object for a lang.
   */
  function locales (lang) {
    let best = new Locales(lang).best(supported)
    return datasource[ best ]
  }

  // noinspection Eslint
  locales.__proto__ = Object.assign(new Function(''), {
    src: dirname,
    defaultLang: defaultLang,
    langs: langs,
    print () {
      print(locales)
      return locales
    },
    validate () {
      validate(locales)
      return locales
    },
    toJSON() {
      return langs.reduce((result, lang) => Object.assign(result, {
        [lang]: locales(lang).toJSON()
      }), {})
    }
  })
  Object.assign(locales, datasource)

  return locales
}

module.exports = apemanlocale
